graphium.data
====================
module for loading datasets and collating batches

=== "Contents"

    * [Data Module](#data-module)
    * [Collate Module](#collate-module)
    * [Util Functions](#util-functions)

## Data Module
------------
::: graphium.data.datamodule


## Collate Module
------------
::: graphium.data.collate


## Util Functions
------------
::: graphium.data.utils
